function matlabbatch = teach_glm_physio_subject(dataDir,derivs,regType,doRun)

% teach_glm_subject_physio(dataDir,derivs,regType,doRun) performs/sets up a first level analysis.
% Inputs:   dataDir -   path to the folder of one subject
%                       folders are located
%           derivs  -   use derivativs =1 or not =0
%           regType -   number defining which regressors to use
%                       if 1 -> button press regressor to study motor
%                       activity
%                       if 2 -> direction of arrow regressor to study motor
%                       activity
%                       if 3 -> Wedge regressor to study retinotopy
%           doRun   -   if 0 or not defined -> just create struct
%                       if 1 -> run directly
%                       if 2 -> run interactively (open Batch editor with
%                       analysis)
%           
%
% Outputs: matlabbatch  -  batch containing information about analysis.
%
% Created: Nov 2019, Jakob Heinzle, Translational neuromodeling Unit, IBT
% University and ETH Zrich

if nargin < 4
    doRun =0;
end


if regType ==1
    glmType= 'LRPress'; % define which regressors to use LRArrow, LRPress, or Wedge
elseif regType ==2
    glmType= 'LRArrow';
elseif regType ==3
    glmType= 'Wedge';
else
    error('Unknown regtype!');
end

physioDir = fullfile(dataDir,'physio');

if derivs % use derivatives
    glmDir=fullfile(dataDir,'glm',sprintf('%s_physio_derivs',glmType));
    derivVec = [1 1];
    funcReg =[1 2 3; 4 5 6];
    nFuncReg = numel(funcReg);
else
    glmDir=fullfile(dataDir,'glm',sprintf('%s_physio_noderivs',glmType));
    derivVec = [0 0];
    funcReg =[1;2];
    nFuncReg = numel(funcReg);
end

mkdir(glmDir);

matlabbatch{1}.spm.stats.fmri_spec.dir = cellstr(glmDir);
matlabbatch{1}.spm.stats.fmri_spec.timing.units = 'secs';
matlabbatch{1}.spm.stats.fmri_spec.timing.RT = 2.2;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t = 32;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t0 = 16;
for k=1:2 % cycle over runs.
    % load the data: Here s8wafmri..., Change next line if this is
    % different.
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).scans = cellstr(spm_select('ExtFPList',fullfile(dataDir,'functional'),sprintf('s8wafmri%02.0f.nii',k),Inf));
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).cond = struct('name', {}, 'onset', {}, 'duration', {}, 'tmod', {}, 'pmod', {}, 'orth', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).multi = cellstr(fullfile(dataDir,'behav',sprintf('%sRegs%02.0f.mat',glmType,k)));
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).regress = struct('name', {}, 'val', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).multi_reg = cellstr(fullfile(physioDir,sprintf('physio_regressors_run%02.0f.txt',k)));
    matlabbatch{1}.spm.stats.fmri_spec.sess(k).hpf = 128;
end
matlabbatch{1}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{1}.spm.stats.fmri_spec.bases.hrf.derivs = derivVec;
matlabbatch{1}.spm.stats.fmri_spec.volt = 1;
matlabbatch{1}.spm.stats.fmri_spec.global = 'None';
matlabbatch{1}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{1}.spm.stats.fmri_spec.mask = {''};
matlabbatch{1}.spm.stats.fmri_spec.cvi = 'AR(1)';
matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('fMRI model specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{3}.spm.stats.con.consess{1}.fcon.name = 'Main Effect';
matlabbatch{3}.spm.stats.con.consess{1}.fcon.weights = eye(nFuncReg);
matlabbatch{3}.spm.stats.con.consess{1}.fcon.sessrep = 'repl';



matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = 'Left > Right';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=1; conVec(funcReg(2,1))=-1;
matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'repl';

matlabbatch{3}.spm.stats.con.consess{3}.tcon.name = 'Right > Left';
conVec = zeros(1,nFuncReg); conVec(funcReg(1,1))=-1; conVec(funcReg(2,1))=1;
matlabbatch{3}.spm.stats.con.consess{3}.tcon.weights = conVec;
matlabbatch{3}.spm.stats.con.consess{3}.tcon.sessrep = 'repl';

% Define physio contrasts etc. 
% All noise regs
matlabbatch{3}.spm.stats.con.consess{4}.fcon.name = 'Effect of noise regs';
matlabbatch{3}.spm.stats.con.consess{4}.fcon.weights = [zeros(25,nFuncReg) eye(25)];
matlabbatch{3}.spm.stats.con.consess{4}.fcon.sessrep = 'repl';
% All physio regs
matlabbatch{3}.spm.stats.con.consess{5}.fcon.name = 'Effect of physio regs';
matlabbatch{3}.spm.stats.con.consess{5}.fcon.weights = [zeros(19,nFuncReg) eye(19)];
matlabbatch{3}.spm.stats.con.consess{5}.fcon.sessrep = 'repl';
% Heart beat related regressors 
matlabbatch{3}.spm.stats.con.consess{6}.fcon.name = 'Effect of heart beat regs';
matlabbatch{3}.spm.stats.con.consess{6}.fcon.weights = [zeros(6,nFuncReg) eye(6)];
matlabbatch{3}.spm.stats.con.consess{6}.fcon.sessrep = 'repl';
% Breathing related regressors 
matlabbatch{3}.spm.stats.con.consess{7}.fcon.name = 'Effect of breathing regs';
matlabbatch{3}.spm.stats.con.consess{7}.fcon.weights = [zeros(8,nFuncReg+6) eye(8)];
matlabbatch{3}.spm.stats.con.consess{7}.fcon.sessrep = 'repl';
% Head motion
matlabbatch{3}.spm.stats.con.consess{8}.fcon.name = 'Effect of motion';
matlabbatch{3}.spm.stats.con.consess{8}.fcon.weights = [zeros(6,nFuncReg+19) eye(6)];
matlabbatch{3}.spm.stats.con.consess{8}.fcon.sessrep = 'repl';
% Respiratory volume per time
matlabbatch{3}.spm.stats.con.consess{9}.fcon.name = 'Effect of RVT';
matlabbatch{3}.spm.stats.con.consess{9}.fcon.weights = [zeros(1,nFuncReg+18) 1];
matlabbatch{3}.spm.stats.con.consess{9}.fcon.sessrep = 'repl';
matlabbatch{3}.spm.stats.con.delete = 1;

if doRun == 2
    spm_jobman('initcfg');
    spm_jobman('interactive',matlabbatch);
elseif doRun == 1
    spm_jobman('initcfg');
    spm_jobman('run',matlabbatch);
end
