function matlabbatch = teach_physio_subject(dataDir, run)

% matlabbatch = teach_physio_subject(dataDir, run)
% Performs / sets up a preprocessing pipeline.
%
% Inputs:
%       dataDir: Path to subject data folder (must contain structural/ and
%                 functional/ subfolders)
%       run:      if 0 -> just create struct [default]
%                 if 1 -> run directly
%                 if 2 -> run interactively (open Batch editor with analysis)
%
% Outputs:
%       matlabbatch: batch containing information about analysis.
%
% Created: Oct 2018, Jakob Heinzle, Translational Neuromodeling Unit, IBT
% University and ETH Zurich

if nargin < 2
    run = 0;
end

% Check whether data folder exists.
if ~exist(dataDir, 'dir')
    error('Could not find specified data folder');
end
% Check whether subfolders exist.
physlogDir = fullfile(dataDir, 'physlog');
if ~exist(physlogDir, 'dir')
    error('Could not find physlog/ subfolder');
end
physioDir = fullfile(dataDir, 'physio'); 
mkdir(physioDir);
funcDir = fullfile(dataDir, 'functional');
if ~exist(funcDir, 'dir')
    error('Could not find functional/ subfolder');
end

% Find out where the Tissue Probability Maps (TPMs) of SPM are located
% on your computer.

matlabbatch = {};
%--------------------------------------------------------------------------
% Slice timing correction
matlabbatch{1}.spm.tools.physio.save_dir = {physioDir};
matlabbatch{1}.spm.tools.physio.log_files.vendor = 'Philips';
matlabbatch{1}.spm.tools.physio.log_files.cardiac = {fullfile(physlogDir,'physlog_fmri01.log')};
matlabbatch{1}.spm.tools.physio.log_files.respiration = {fullfile(physlogDir,'physlog_fmri01.log')};
matlabbatch{1}.spm.tools.physio.log_files.scan_timing = {''};
matlabbatch{1}.spm.tools.physio.log_files.sampling_interval = [];
matlabbatch{1}.spm.tools.physio.log_files.relative_start_acquisition = 0;
matlabbatch{1}.spm.tools.physio.log_files.align_scan = 'last';
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.Nslices = 32;
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.NslicesPerBeat = [];
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.TR = 2.2;
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.Ndummies = 1;
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.Nscans = 145;
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.onset_slice = 16;
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.time_slice_to_slice = [];
matlabbatch{1}.spm.tools.physio.scan_timing.sqpar.Nprep = [];
matlabbatch{1}.spm.tools.physio.scan_timing.sync.gradient_log.grad_direction = 'z';
matlabbatch{1}.spm.tools.physio.scan_timing.sync.gradient_log.zero = 0.7;
matlabbatch{1}.spm.tools.physio.scan_timing.sync.gradient_log.slice = 0.8;
matlabbatch{1}.spm.tools.physio.scan_timing.sync.gradient_log.vol = [];
matlabbatch{1}.spm.tools.physio.scan_timing.sync.gradient_log.vol_spacing = [];
matlabbatch{1}.spm.tools.physio.preproc.cardiac.modality = 'ECG';
matlabbatch{1}.spm.tools.physio.preproc.cardiac.filter.no = struct([]);
matlabbatch{1}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.min = 0.4;
matlabbatch{1}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.file = 'initial_cpulse_kRpeakfile.mat';
matlabbatch{1}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.max_heart_rate_bpm = 90;
matlabbatch{1}.spm.tools.physio.preproc.cardiac.posthoc_cpulse_select.off = struct([]);
matlabbatch{1}.spm.tools.physio.model.output_multiple_regressors = 'physio_regressors_run01.txt';
matlabbatch{1}.spm.tools.physio.model.output_physio = 'physio_run01.mat';
matlabbatch{1}.spm.tools.physio.model.orthogonalise = 'none';
matlabbatch{1}.spm.tools.physio.model.censor_unreliable_recording_intervals = false;
matlabbatch{1}.spm.tools.physio.model.retroicor.yes.order.c = 3;
matlabbatch{1}.spm.tools.physio.model.retroicor.yes.order.r = 4;
matlabbatch{1}.spm.tools.physio.model.retroicor.yes.order.cr = 1;
matlabbatch{1}.spm.tools.physio.model.rvt.yes.delays = 0;
%matlabbatch{1}.spm.tools.physio.model.hrv.yes.delays = 0;
matlabbatch{1}.spm.tools.physio.model.noise_rois.no = struct([]);
matlabbatch{1}.spm.tools.physio.model.movement.yes.file_realignment_parameters = {fullfile(funcDir,'rp_afmri01.txt')};
matlabbatch{1}.spm.tools.physio.model.movement.yes.order = 6;
matlabbatch{1}.spm.tools.physio.model.movement.yes.censoring_method = 'FD';
matlabbatch{1}.spm.tools.physio.model.movement.yes.censoring_threshold = 0.5;
matlabbatch{1}.spm.tools.physio.model.other.no = struct([]);
matlabbatch{1}.spm.tools.physio.verbose.level = 2;
matlabbatch{1}.spm.tools.physio.verbose.fig_output_file = 'physio.fig';
matlabbatch{1}.spm.tools.physio.verbose.use_tabs = false;
matlabbatch{2}.spm.tools.physio.save_dir = {physioDir};
matlabbatch{2}.spm.tools.physio.log_files.vendor = 'Philips';
matlabbatch{2}.spm.tools.physio.log_files.cardiac = {fullfile(physlogDir,'physlog_fmri02.log')};
matlabbatch{2}.spm.tools.physio.log_files.respiration = {fullfile(physlogDir,'physlog_fmri02.log')};
matlabbatch{2}.spm.tools.physio.log_files.scan_timing = {''};
matlabbatch{2}.spm.tools.physio.log_files.sampling_interval = [];
matlabbatch{2}.spm.tools.physio.log_files.relative_start_acquisition = 0;
matlabbatch{2}.spm.tools.physio.log_files.align_scan = 'last';
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.Nslices = 32;
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.NslicesPerBeat = [];
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.TR = 2.2;
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.Ndummies = 1;
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.Nscans = 145;
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.onset_slice = 16;
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.time_slice_to_slice = [];
matlabbatch{2}.spm.tools.physio.scan_timing.sqpar.Nprep = [];
matlabbatch{2}.spm.tools.physio.scan_timing.sync.gradient_log.grad_direction = 'z';
matlabbatch{2}.spm.tools.physio.scan_timing.sync.gradient_log.zero = 0.7;
matlabbatch{2}.spm.tools.physio.scan_timing.sync.gradient_log.slice = 0.8;
matlabbatch{2}.spm.tools.physio.scan_timing.sync.gradient_log.vol = [];
matlabbatch{2}.spm.tools.physio.scan_timing.sync.gradient_log.vol_spacing = [];
matlabbatch{2}.spm.tools.physio.preproc.cardiac.modality = 'ECG';
matlabbatch{2}.spm.tools.physio.preproc.cardiac.filter.no = struct([]);
matlabbatch{2}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.min = 0.4;
matlabbatch{2}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.file = 'initial_cpulse_kRpeakfile.mat';
matlabbatch{2}.spm.tools.physio.preproc.cardiac.initial_cpulse_select.auto_matched.max_heart_rate_bpm = 90;
matlabbatch{2}.spm.tools.physio.preproc.cardiac.posthoc_cpulse_select.off = struct([]);
matlabbatch{2}.spm.tools.physio.model.output_multiple_regressors = 'physio_regressors_run02.txt';
matlabbatch{2}.spm.tools.physio.model.output_physio = 'physio_run02.mat';
matlabbatch{2}.spm.tools.physio.model.orthogonalise = 'none';
matlabbatch{2}.spm.tools.physio.model.censor_unreliable_recording_intervals = false;
matlabbatch{2}.spm.tools.physio.model.retroicor.yes.order.c = 3;
matlabbatch{2}.spm.tools.physio.model.retroicor.yes.order.r = 4;
matlabbatch{2}.spm.tools.physio.model.retroicor.yes.order.cr = 1;
matlabbatch{2}.spm.tools.physio.model.rvt.yes.delays = 0;
matlabbatch{2}.spm.tools.physio.model.hrv.yes.delays = 0;
matlabbatch{2}.spm.tools.physio.model.noise_rois.no = struct([]);
matlabbatch{2}.spm.tools.physio.model.movement.yes.file_realignment_parameters = {fullfile(funcDir,'rp_afmri02.txt')};
matlabbatch{2}.spm.tools.physio.model.movement.yes.order = 6;
matlabbatch{2}.spm.tools.physio.model.movement.yes.censoring_method = 'FD';
matlabbatch{2}.spm.tools.physio.model.movement.yes.censoring_threshold = 0.5;
matlabbatch{2}.spm.tools.physio.model.other.no = struct([]);
matlabbatch{2}.spm.tools.physio.verbose.level = 2;
matlabbatch{2}.spm.tools.physio.verbose.fig_output_file = 'physio.fig';
matlabbatch{2}.spm.tools.physio.verbose.use_tabs = false;

if run == 2
    spm_jobman('initcfg');
    spm_jobman('interactive',matlabbatch);
elseif run == 1
    spm_jobman('initcfg');
    spm_jobman('run',matlabbatch);
end
